@@ -4,7 +4,7 @@ use Catmandu::Sane;
 use Moo;
 use namespace::clean;
 
-our $VERSION = "0.07";
+our $VERSION = "0.0701";
 
 with 'Catmandu::Store::DBI::Handler';
 
@@ -30,8 +30,9 @@ sub _column_sql {
         $sql .= 'DATETIME';
     }
     elsif ($map->{type} eq 'datetime_milli') {
-        if ($dbh->{mysql_clientversion} < 50640)  {
-            Catmandu::NotImplemented->throw("DATETIME(3) only for MySQL > 5.6.4");
+        if ($dbh->{mysql_clientversion} < 50640) {
+            Catmandu::NotImplemented->throw(
+                "DATETIME(3) only for MySQL > 5.6.4");
         }
         $sql .= 'DATETIME(3)';
     }
